Crate bevy_mod_scripting_derive

Crate bevy_mod_scripting_derive 

Derive macros for BMS

Macros

impl_get_type_dependencies
Proc macro equivalent of GetTypeDependencies which does not generate a type, purely the impl. Useful for generating implementations against remote types.

Attribute Macros

script_bindings
Derive macro for generating script bindings from an impl block.
script_globals
Derive macro for generating script globals from an impl block.

Derive Macros

ArgMeta
Default implementation for the TypedThrough trait
DebugWithTypeInfo
Derive macro for generating Debug implementations which include type information. Uses the DebugWithTypeInfoBuilder trait from bevy_mod_scripting_display to generate the debug output.
FromScript
Default implementation for the IntoScript trait
GetTypeDependencies
Derive macro for generating GetTypeDependencies implementations.
IntoScript
Default implementation for the IntoScript trait
TypedThrough
Default implementation for the TypedThrough trait